==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pl/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Pola niestandardowe',
    'field'		                => 'Pole',
    'about_fieldsets_title'		=> 'O zestawie pól',
    'about_fieldsets_text'		=> 'Zestawy pól pozwalają tworzyć grupy pól niestandardowych, które często są używane dla specyficznych typów modeli.',
    'custom_format'             => 'Własny format...',
    'encrypt_field'      	        => 'Szyfruje wartość tego pola w bazie danych',
    'encrypt_field_help'      => 'UWAGA: Szyfrowanie pola spowoduje brak możliwości wyszukiwania go.',
    'encrypted'      	        => 'Zaszyfrowane',
    'fieldset'      	        => 'Zestaw pól',
    'qty_fields'      	      => 'Ilość pól',
    'fieldsets'      	        => 'Zestaw pól',
    'fieldset_name'           => 'Nazwa zestawu pól',
    'field_name'              => 'Nazwa Pola',
    'field_values'            => 'Wartości pól',
    'field_values_help'       => 'Dodaj opcje zaznaczania, jeden na wiersz. Puste wiersze poza pierwszym wierszem będą ignorowane.',
    'field_element'           => 'Element formularza',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format niestandardowy',
    'field_custom_format_help'     => 'To pole umożliwia użycie wyrażenia regularnego do sprawdzania poprawności. Wyrażenie powinno zaczynać się od "regex:" - na przykład, aby sprawdzić, czy niestandardowa wartość pola zawiera poprawny IMEI (15 cyfr), trzeba użyć <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Wymagane',
    'req'   		              => 'Wymagane',
    'used_by_models'   		    => 'Używane przez modele',
    'order'   		            => 'Kolejność',
    'create_fieldset'         => 'Nowy zestaw pól',
    'create_field'            => 'Nowe pole niestandardowe',
    'value_encrypted'      	        => 'Wartość tego pola jest zaszyfrowana w bazie danych. Tylko admini będą mogli wyświetlić rozszyfrowaną wartość',
    'show_in_email'     => 'Czy podać wartość tego pola w e-mailach z przypisaniem, wysłanych do użytkownika? Zaszyfrowane pola nie mogą być zawarte w wiadomościach e-mail.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pl/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Pola niestandardowe',
    'manage'                    => 'Zarządzaj',
    'field'		                => 'Pole',
    'about_fieldsets_title'		=> 'O zestawie pól',
    'about_fieldsets_text'		=> 'Zestawy pól pozwalają na utworzenie grup własnych, niestandardowych pól, które są często wykorzystywane. Mogą być one wykorzystane i przypisane do modeli aktywów.',
    'custom_format'             => 'Własny format...',
    'encrypt_field'      	        => 'Szyfruje wartość tego pola w bazie danych',
    'encrypt_field_help'      => 'UWAGA: Szyfrowanie pola spowoduje brak możliwości wyszukiwania go.',
    'encrypted'      	        => 'Zaszyfrowane',
    'fieldset'      	        => 'Zestaw pól',
    'qty_fields'      	      => 'Ilość pól',
    'fieldsets'      	        => 'Zestaw pól',
    'fieldset_name'           => 'Nazwa zestawu pól',
    'field_name'              => 'Nazwa Pola',
    'field_values'            => 'Wartości pól',
    'field_values_help'       => 'Dodaj opcje zaznaczania, jeden na wiersz. Puste wiersze poza pierwszym wierszem będą ignorowane.',
    'field_element'           => 'Element formularza',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format niestandardowy',
    'field_custom_format_help'     => 'To pole umożliwia użycie wyrażenia regularnego do sprawdzania poprawności. Wyrażenie powinno zaczynać się od "regex:" - na przykład, aby sprawdzić, czy niestandardowa wartość pola zawiera poprawny IMEI (15 cyfr), trzeba użyć <code>regex: / ^[0-9]{15}$ /</code>.',
    'required'   		          => 'Wymagane',
    'req'   		              => 'Wymagane',
    'used_by_models'   		    => 'Używane przez modele',
    'order'   		            => 'Kolejność',
    'create_fieldset'         => 'Nowy zestaw pól',
    'create_fieldset_title' => 'Utwórz nową listę',
    'create_field'            => 'Nowe pole niestandardowe',
    'create_field_title' => 'Utwórz pole niestandardowe',
    'value_encrypted'      	        => 'Wartość tego pola jest zaszyfrowana w bazie danych. Tylko admini będą mogli wyświetlić rozszyfrowaną wartość',
    'show_in_email'     => 'Czy podać wartość tego pola w e-mailach z przypisaniem, wysłanych do użytkownika? Zaszyfrowane pola nie mogą być zawarte w wiadomościach e-mail.',
    'help_text' => 'Tekst pomocniczy',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'O polach niestandardowych',
    'about_custom_fields_text' => 'Pola niestandardowe pozwalają na dodawanie dowolnych atrybutów do środków trwałych.',
    'add_field_to_fieldset' => 'Dodaj pole do listy pól',
    'make_optional' => 'Wymagane - kliknij, aby ustawić jako opcjonalne',
    'make_required' => 'Opcjonalnie - kliknij, aby ustawić jako wymagane',
    'reorder' => 'Zmień kolejność',
    'db_field' => 'Pole bazy danych',
    'db_convert_warning' => 'UWAGA. To pole znajduje się w tabeli pól niestandardowych jako <code> :db_column </code> ale powinno być :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
